\name{getIBDs}
\alias{getIBDs}
\title{getIBDs: Function to extract haplotype clusters / IBD tracts from \code{fabia} results}
\description{

  \code{getIBDs}: \R implementation of \code{getIBDs}.

  Haplotype clusters or IBD tracts are identified in FABIA results.
  First accumulations of correlated SNVs/SNPs are found.
  Then haplotype clusters in these accumulations are disentangled.
  Finally haplotype clusters are pruned off spurious correlated SNVs.


}
\usage{

getIBDs(res,sPF,annot=NULL,chrom=1,labelsA=NULL,ps=0.9,psZ=0.8,inteA=500,thresA=11,minSNPs=8,off=0,procMinSamps=0.1,thresPrune=1e-3)


}
\arguments{
  \item{res}{result of \code{fabia}.}
  \item{sPF}{result obtained by \code{fabia} procedure \code{samplesPerFeature}; it gives for each SNV the samples that possess the minor allele.}
  \item{annot}{annotation for the SNVs; if it is \code{NULL} then a dummy annotation is generated.}
  \item{chrom}{the chromosome.}
  \item{labelsA}{labels for the samples; if it is \code{NULL} then a dummy labels by enumerating samples are generated.}
 \item{ps}{quantile above which the L values are considered for IBD/haplotype cluster extraction.}
  \item{psZ}{quantile above which the largest Z values are considered for IBD/haplotype cluster extraction.}
  \item{inteA}{number of SNVs in a histogram bin which correspond to the
    desired haplotype cluster length; \code{inteA} can be computed from \code{IBDlength}, the haplotype cluster length in kbp, via \code{inteA}=\code{IBDlength}*10 assuming an average distance between SNVs of 100 bases.}
  \item{thresA}{threshold for histogram counts beyond which SNVs are
    viewed to be locally accumulated in a histogram bin
    more than expected randomly.}
  \item{minSNPs}{minimal number of minor alleles of an
    individual that must agree to the haplotype cluster tagSNVs
    to consider the individual as belonging to the haplotype cluster.}
   \item{off}{offset of the histogram.}
   \item{procMinSamps}{percent of individuals that belong to the
     haplotype cluster that must have the minor allele to consider a SNV as haplotype cluster tagSNV.}
   \item{thresPrune}{threshold on the probability of having such a large
     distance to a neigboring tagSNV in order to prune off SNVs at the border of haplotype cluster.}
}
\details{


  The threshold  \code{thresA} for counts in a bin indicating
  accumulations is supplied and computed in
  \code{hapFabia}.
  Pruning is based on an exponential distribution with
  the median distance between tagCNVs as parameter (one over the rate).
  Therefore the counts are assumed to be Poisson distributed.
  CNVs that are at the haplotype cluster border and have a considerable larger
  distance to the next tagSNVs closer to the haplotype cluster center are pruned off.
  \code{thresPrune} gives the pruning threshold via a \eqn{p}{p}-value for
  observing this distance or a larger based on the exponential distribution.

  Implementation in \R.

}
\value{
list of lists where the latter contain:
  \item{number}{number of haplotype clusters in current extraction procedure.}
  \item{bicluster}{ID of the bicluster the haplotype cluster was found in.}
  \item{chrom}{the chromosome.}
  \item{ibdPos}{genomic location of the haplotype cluster.}
  \item{ibdLength}{length of the haplotype cluster.}
  \item{numberSamples}{number of samples belonging to the haplotype cluster.}
  \item{numberSnps}{number tagSNVs of the haplotype cluster.}
  \item{noSamples}{samples IDs of samples belonging to the haplotype cluster.}
  \item{noSnps}{SNV IDs of the haplotype cluster tagSNVs.}
  \item{countrySamples}{second label of samples.}
  \item{idSamples}{sample names; first label of samples.}
  \item{labelSamples}{third label of samples.}
  \item{techSamples}{technology used; fourth label of samples.}
  \item{maxSamples}{IDs of samples building the core haplotype cluster.}
  \item{snpPositions}{physical positions of the SNVs on the chromosome in bases.}
  \item{snpAlleles}{alleles in the form \code{Ref:Alt} where Ref denotes reference allele and Alt the alternative allele.}
  \item{snpNames}{name of SNVs according to annotation.}
  \item{snpFreq}{frequency of SNVs in whole population.}
  \item{snpGroupFreq}{frequency of SNVs in population that is considered.}
  \item{snpChange}{if the minor allele was more frequent than the major, then both were switched.}
  \item{snpsPerSample}{for each sample: tagSNVs are counted for which the sample has the minor allele.}
  \item{samplePerSnp}{for each CNV: samples are counted for which the CNV has its minor allele.}

    }
\seealso{
\code{\link{hapFabia}},
\code{\link{vcftoFABIA}},
\code{\link{split_sparse_matrix}},
\code{\link{iterateSegments}},
\code{\link{getIBDs}},
\code{\link{extractIBD}},
\code{\link{compareIBDres}},
\code{\link{mergeIBDres}},
\code{\link{identifyDuplicates}},
\code{\link{ibd2excel}},
\code{\link{plotRangeL}},
\code{\link{plotOneIBD}},
\code{\link{plotIBDs}},
\code{\link{snpPlot}},
\code{\link{analyzeIBDs}},
\code{\link{simulateHaplotypes}},
\code{\link{simulateForFabia}},
\code{\link{sim}},
\code{\link{topLZ}},
\code{\link{histL}},
\code{\link{plotL}},
\code{\link{hapRes}},
\code{\link{res}},
\code{\link{simu}},
\code{\link{mergedIBD}}
}
\author{Sepp Hochreiter}
\examples{

data(hapRes)
res <- hapRes$res
sPF <- hapRes$sPF
annot <- hapRes$annot
nnL <- length(res@Z[1,])
labelsA <- cbind(as.character(1:nnL),as.character(1:nnL),as.character(1:nnL),as.character(1:nnL))
resIBD1 <- getIBDs(res=res,sPF=sPF,annot=annot,chrom=1,labelsA=labelsA,ps=0.9,inteA=50,thresA=6,minSNPs=6,off=0)
print(resIBD1[[1]]$ibdPos)
print(resIBD1[[1]]$ibdLength)

}

\references{

S. Hochreiter et al.,
\sQuote{FABIA: Factor Analysis for Bicluster Acquisition},
Bioinformatics 26(12):1520-1527, 2010.

}
\keyword{models,multivariate,cluster}
\concept{genetics,haplotype,identity by descent,bicluster,next generation sequencing,genotype,single nucleotide polymorphism,single nucleotide variation,rare variants,rare SNPs, rare SNVs,rare haplotype clusters,short haplotype clusters}
